/*
    Copyright (c) 2010, 2011 aizo ag, Zurich, Switzerland

    Author: Sergey 'Jin' Bostandzhyan <jin@dev.digitalstrom.org>

    This file is part of dS Assistant.

    dS-Assistant is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    dS-Assistant is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with digitalSTROM Server. If not, see <http://www.gnu.org/licenses/>.

    NOTE: all APIs, especially the JSON API, offered by this application
          are subject to change without further notice.
*/

#ifndef __CONFIG_MANAGER_H__
#define __CONFIG_MANAGER_H__

#include <string>
#include <vector>

#include "exceptions.h"
#include "config_options.h"

namespace dSA
{

enum ConfigOptions
{
    CFG_CONFIG_FILE = 0,
    CFG_WEBSERVER_PORT,
    CFG_WEBSERVER_INTERFACE,
    CFG_WEBSERVER_DOCUMENT_ROOT,
    CFG_DS485_DAEMON_URL,
    CFG_DATABASE_FILE,
    CFG_LOG_DIR,
    CFG_LOG_LEVEL,
    CFG_MAX
};

class ConfigManager
{
public:
    static ConfigManager* createInstance(const char *config_file,
                                         const char *webroot,
                                         int webport);
    static ConfigManager* getInstance();


    const std::string& getOption(ConfigOptions option) const;
    const int getIntOption(ConfigOptions option) const;
    const bool getBoolOption(ConfigOptions option) const;

    ~ConfigManager();
protected:
    ConfigManager(const char* config_file, const char* webroot,
                  int webport);
    std::vector<GenericOption *> m_options;

private:
    ConfigManager();
    static ConfigManager* m_instance;
};

}; // namespace

#endif//__CONFIG_MANAGER_H__
